<?php

namespace Bydedi\Flux\GoogleShopping\Exception;

use Exception;

/**
 * Class LengthParamException
 * @package Bydedi\Flux\GoogleShopping\Exception
 */
class LengthParamException extends Exception
{

    /**
     * LengthParamException constructor.
     * @param string $paramName
     * @param int $paramLength
     * @param int $authorizedLength
     * @param array $authorizedFixedLength
     * @param int $code
     * @param Exception|null $previous
     */
    public function __construct($paramName, $paramLength, $authorizedLength = 0, $authorizedFixedLength = array(), $code = 0, Exception $previous = null)
    {
        $message = "";
        
        if ($authorizedLength != 0) {
            $message .= sprintf("Value of param %s is too long (Actual : %s, Max : %s)\n", $paramName, $paramLength, $authorizedLength);
        }
        
        if (!empty($authorizedFixedLength)) {
            $message .= sprintf("Length of param %s is wrong. (Actual : %s, Authorized : %s)",
                                $paramName,
                                $paramLength,
                                implode(" / " . $authorizedFixedLength));
        }
        
        parent::__construct($message, $code, $previous);
    }

    /**
     * @return string
     */
    public function __toString()
    {
        return __CLASS__ . ": [{$this->code}]: {$this->message}\n";
    }
}